@@ -7,7 +7,8 @@ from dbt.adapters.sql import SQLConnectionManager
 from dbt.contracts.connection import AdapterResponse
 from dbt.contracts.connection import Connection
 from dbt.adapters.base import Credentials
-from dbt.logger import GLOBAL_LOGGER as logger
+from dbt.events import AdapterLogger
+logger = AdapterLogger("teradata")
 from dataclasses import dataclass
 from typing import Optional, Tuple, Any
 
