@@ -1,7 +1,7 @@
 
 {% macro teradata__list_schemas(database) %}
     {% call statement('list_schemas', fetch_result=True, auto_begin=False) -%}
-        select distinct DatabaseName as schema_name
+        select DatabaseName as schema_name
         from {{ information_schema_name(database) }}.DatabasesV
     {%- endcall %}
 
@@ -63,7 +63,7 @@
 {% endmacro %}
 
 {% macro teradata__current_timestamp() -%}
-CAST ( CAST (CURRENT_TIMESTAMP AS FORMAT 'YYYY-MM-DD HH:MI:SS.S(F)Z') AS VARCHAR(32))
+CURRENT_TIMESTAMP(6)
 {%- endmacro %}
 
 {% macro teradata__rename_relation(from_relation, to_relation) -%}
@@ -106,7 +106,6 @@ CAST ( CAST (CURRENT_TIMESTAMP AS FORMAT 'YYYY-MM-DD HH:MI:SS.S(F)Z') AS VARCHAR
         when ColumnsV.ColumnType = 'D' then 'DECIMAL'
         when ColumnsV.ColumnType = 'DA' then 'DATE'
         when ColumnsV.ColumnType = 'F' then 'DOUBLE PRECISION'
-        when ColumnsV.ColumnType = 'F' then 'FLOAT'
         when ColumnsV.ColumnType = 'I' then 'INTEGER'
         when ColumnsV.ColumnType = 'DY' then 'INTERVAL DAY'
         when ColumnsV.ColumnType = 'DH' then 'INTERVAL DAY TO HOUR'
@@ -153,11 +152,11 @@ CAST ( CAST (CURRENT_TIMESTAMP AS FORMAT 'YYYY-MM-DD HH:MI:SS.S(F)Z') AS VARCHAR
       ColumnsV.ColumnID as column_index
     from
     {% if use_qvci == True -%}
-      DBC.ColumnsJQV as ColumnsV
+      {{ information_schema_name(relation.schema) }}.ColumnsJQV as ColumnsV
     {% else %}
-      DBC.ColumnsV
+      {{ information_schema_name(relation.schema) }}.ColumnsV
     {%- endif %}
-    left outer join DBC.TablesV
+    left outer join {{ information_schema_name(relation.schema) }}.TablesV
       on ColumnsV.DatabaseName = TablesV.DatabaseName
       and ColumnsV.TableName = TablesV.TableName
     where
@@ -183,7 +182,7 @@ CAST ( CAST (CURRENT_TIMESTAMP AS FORMAT 'YYYY-MM-DD HH:MI:SS.S(F)Z') AS VARCHAR
          when TableKind = 'V' then 'view'
          else TableKind
       end as table_type
-    from DBC.TablesV
+    from {{ information_schema_name(schema_relation.schema) }}.TablesV
     where DatabaseName = '{{ schema_relation.schema }}' (NOT CASESPECIFIC)
       and TableKind in ('T', 'V')
 
